@@ -1,11 +1,14 @@
 import logging
 import os
 import time
+import pathlib
 import traceback
 from typing import Optional
+import git
 
 import toml
-from binsync.core.client import ConnectionWarnings
+from binsync.core.client import ConnectionWarnings, BINSYNC_ROOT_BRANCH
+from binsync.data.configuration import ProjectConfig
 from binsync.common.ui.qt_objects import (
     QCheckBox,
     QDialog,
@@ -29,10 +32,11 @@ class SyncConfig(QDialog):
     - cloning a remote
     - using a locally pulled remote repo
     """
-    def __init__(self, controller, open_magic_sync=True, parent=None):
+    def __init__(self, controller, open_magic_sync=True, load_config=True, parent=None):
         super().__init__(parent)
         self.controller = controller
         self.open_magic_sync = open_magic_sync
+        self.should_load_config = load_config
         self.setWindowTitle("Configure BinSync")
 
         self._main_layout = QVBoxLayout()
@@ -51,6 +55,10 @@ class SyncConfig(QDialog):
         # user label
         user_label = QLabel(self)
         user_label.setText("User name")
+        user_label.setToolTip(
+            "The name your user will be saved as on remote. Can be anything other that 'root'. This name does not "
+            "need to be the same as your Git username."
+        )
 
         self._user_edit = QLineEdit(self)
 
@@ -62,6 +70,11 @@ class SyncConfig(QDialog):
         # binsync label
         binsync_label = QLabel(self)
         binsync_label.setText("Git repo")
+        binsync_label.setToolTip(
+            "The path to a locally cloned Git repo. This can be ignored if you have not cloned down a remote "
+            "repo yet, but you have the URL. The local repo can also be an empty folder that will be turned into "
+            "a BinSync database by selecting 'init_remote'."
+        )
 
         # repo path
         self._repo_edit = QLineEdit(self)
@@ -80,19 +93,29 @@ class SyncConfig(QDialog):
         row += 1
 
         # clone from a remote URL
-        remote_label = QLabel(self)
-        remote_label.setText("Remote URL")
+        self.remote_label = QLabel(self)
+        self.remote_label.setText("Remote URL")
+        self.remote_label.setToolTip(
+            "The URL to a remove Git repo. This is not required if you have already selected a locally cloned "
+            "Git repo that has a remote. This repo will be cloned to the same location as your binary if a local "
+            "repo does not exist yet."
+        )
+
+
         self._remote_edit = QLineEdit(self)
 
-        upper_layout.addWidget(remote_label, row, 0)
+        upper_layout.addWidget(self.remote_label, row, 0)
         upper_layout.addWidget(self._remote_edit, row, 1)
         row += 1
 
         # initialize repo checkbox
         self._initrepo_checkbox = QCheckBox(self)
-        self._initrepo_checkbox.setText("Create repository")
-        self._initrepo_checkbox.setToolTip("I'm the first user of this binsync project and I'd "
-                                           "like to initialize it as a sync repo.")
+        self._initrepo_checkbox.setText("Init Remote")
+        self._initrepo_checkbox.setToolTip(
+            "Ether inits the local folder, making it into a Git repo, or updates the remote references of the current "
+            "Git repo to have the correct BinSync layout which includes the root branch and the new user. Should only "
+            "ever be used when first creating a BinSync repo for all users."
+        )
         self._initrepo_checkbox.setChecked(False)
         #self._initrepo_checkbox.setEnabled(False)
 
@@ -118,7 +141,8 @@ class SyncConfig(QDialog):
         self._main_layout.addLayout(buttons_layout)
 
         # change the text if config exists
-        self.load_saved_config()
+        if self.should_load_config:
+            self.load_saved_config()
 
     #
     # Event handlers
@@ -156,8 +180,8 @@ class SyncConfig(QDialog):
             remote_url = None
 
         if remote_url and not path:
-            path = os.path.join(os.path.dirname(self.controller.binary_path()),
-                                os.path.basename(self.controller.binary_path()) + "_bs"
+            path = os.path.join(os.path.dirname(self.controller.binary_path() or ""),
+                                os.path.basename(self.controller.binary_path() or "") + "_bs"
                                 )
 
         try:
@@ -181,7 +205,7 @@ class SyncConfig(QDialog):
         # create and save config if possible
         saved_config = self.save_config()
         if saved_config:
-            l.debug(f"Configuration config was saved to {saved_config}.")
+            l.debug(f"Configuration file was saved to {saved_config}.")
 
         self.close()
 
@@ -195,15 +219,45 @@ class SyncConfig(QDialog):
         self._repo_edit.setText(QDir.toNativeSeparators(directory))
 
     def _on_repo_textchanged(self, new_text):
-        # is it a git repo?
-        if not self.is_git_repo(new_text.strip()):
-            # no it's not
-            # maybe we want to clone from the remote side?
-            self._initrepo_checkbox.setEnabled(True)
+        path = new_text
+        if pathlib.Path(path).exists() and self.is_git_repo(path):
+            repo = git.Repo(path)
+            try:
+                url = repo.remote().url
+            except Exception:
+                url = None
+
+            self._remote_edit.setText(url or "")
+            self._remote_edit.setEnabled(False)
+            self.remote_label.setStyleSheet('color: gray')
+
+            is_binsync_inited = False
+            try:
+                is_binsync_inited = any(ref.name.endswith(BINSYNC_ROOT_BRANCH) for ref in repo.remote().refs)
+            except Exception:
+                pass
+
+            if is_binsync_inited:
+                self._initrepo_checkbox.setChecked(False)
+                self._initrepo_checkbox.setStyleSheet(
+                    'QCheckBox::unchecked { color: gray } '
+                    'QCheckBox::checked { color: gray }'
+                )
+                self._initrepo_checkbox.setEnabled(False)
+            else:
+                self._initrepo_checkbox.setEnabled(True)
+                self._initrepo_checkbox.setStyleSheet(
+                    'QCheckBox::unchecked { color: white } '
+                    'QCheckBox::checked { color: white }'
+                )
         else:
-            # yes it is!
-            # we don't want to initialize it or allow cloning from the remote side
-            self._initrepo_checkbox.setEnabled(False)
+            self._remote_edit.setEnabled(True)
+            self._initrepo_checkbox.setEnabled(True)
+            self.remote_label.setStyleSheet('color: white')
+            self._initrepo_checkbox.setStyleSheet(
+                'QCheckBox::unchecked { color: white } '
+                'QCheckBox::checked { color: white }'
+            )
 
     def _on_cancel_clicked(self):
         self.close()
@@ -212,46 +266,39 @@ class SyncConfig(QDialog):
     # Utils
     #
 
-    def _get_config_path(self):
-        binary_path = self.controller.binary_path()
-        if not binary_path:
-            return None
-
-        # example config: /path/to/fauxware_files/.fauxware.conf.toml
-        config_name = "." + os.path.basename(self.controller.binary_path()) + ".conf.toml"
-        config_path = os.path.join(os.path.dirname(self.controller.binary_path()), config_name)
-        return config_path
-
     def load_saved_config(self) -> bool:
-        config_path = self._get_config_path()
-        if not config_path or not os.path.exists(config_path):
+        config = ProjectConfig.load_from_file(self.controller.binary_path() or "")
+        if not config:
             return False
 
-        with open(config_path, "r") as fp:
-            config = toml.load(fp)
+        user = config.user or ""
+        repo = config.repo_path or ""
+        remote = config.remote if config.remote and not config.repo_path else ""
 
-        self._user_edit.setText(config.get("username", ""))
-        self._repo_edit.setText(config.get("repo", ""))
-        self._remote_edit.setText(config.get("remote", ""))
+        self._user_edit.setText(user)
+        self._repo_edit.setText(repo)
+        self._on_repo_textchanged(repo)
+        self._remote_edit.setText(remote)
         return True
 
     def save_config(self) -> Optional[str]:
-        config_path = self._get_config_path()
-        if not config_path:
-            return None
+        user = self._user_edit.text()
+        remote = self._remote_edit.text()
+        repo = self._repo_edit.text()
 
-        if os.path.exists(config_path):
-            os.unlink(config_path)
+        if remote and not repo:
+            repo = str(pathlib.Path(self.controller.client.repo_root).absolute())
 
-        config = {
-            "username": self._user_edit.text(),
-            "repo": self._repo_edit.text(),
-            "remote": self._remote_edit.text()
-        }
-        with open(config_path, "w") as fp:
-            toml.dump(config, fp)
+        config = ProjectConfig(
+            self.controller.binary_path() or "",
+            user=user,
+            repo_path=repo,
+            remote=remote
+        )
+        if not config:
+            return config
 
-        return config_path
+        return config.save()
 
 
     #
@@ -268,9 +315,9 @@ class SyncConfig(QDialog):
 
         for warning in warnings:
             if warning == ConnectionWarnings.HASH_MISMATCH:
-                warning_text += "Warning: the hash stored for this BinSync project does not match"
-                warning_text += " the hash of the binary you are attempting to analyze. It's possible"
-                warning_text += " you are working on a different binary.\n"
+                warning_text += "Warning: the hash stored for this BinSync project does not match " \
+                                "the hash of the binary you are attempting to analyze. It's possible " \
+                                "you are working on a different binary.\n"
 
         if len(warning_text) > 0:
             QMessageBox.warning(
