@@ -2,6 +2,7 @@ import logging
 import time
 
 import binsync.data
+from binsync.common.ui.force_push.force_push import ForcePushUI
 from binsync.common.ui.panel_tabs.activity_table import QActivityTable
 from binsync.common.ui.panel_tabs.ctx_table import QCTXTable
 from binsync.common.ui.panel_tabs.functions_table import QFunctionTable
@@ -9,6 +10,8 @@ from binsync.common.ui.panel_tabs.globals_table import QGlobalsTable
 from binsync.common.ui.panel_tabs.util_panel import QUtilPanel
 from binsync.common.ui.qt_objects import (
     QLabel,
+    QMenu,
+    QPushButton,
     QStatusBar,
     QTabWidget,
     QVBoxLayout,
@@ -18,6 +21,20 @@ from binsync.common.ui.qt_objects import (
 
 l = logging.getLogger(__name__)
 
+class QContextStatusBar(QStatusBar):
+    def __init__(self, controller, parent = None):
+        super(QContextStatusBar, self).__init__(parent)
+        self.controller = controller
+
+    def contextMenuEvent(self, event):
+        menu = QMenu(self)
+        menu.setObjectName("binsync_context_context_menu")
+        if self.controller.last_ctx:
+            ctx_name = self.controller.last_ctx.name
+            ctx_addr = self.controller.last_ctx.addr
+            menu.addAction(f"Force Push {ctx_name}@{hex(ctx_addr)}", lambda : self.controller.force_push_function(ctx_addr))
+            menu.popup(self.mapToGlobal(event.pos()))
+
 class ControlPanel(QWidget):
     update_ready = Signal()
     ctx_change = Signal()
@@ -69,7 +86,7 @@ class ControlPanel(QWidget):
         # status bar
         self._status_label = QLabel(self)
         self._status_label.setText(self.controller.status_string())
-        self._status_bar = QStatusBar(self)
+        self._status_bar = QContextStatusBar(self.controller, self)
         self._status_bar.addPermanentWidget(self._status_label)
 
         # control box
@@ -100,6 +117,9 @@ class ControlPanel(QWidget):
         main_layout = QVBoxLayout()
         main_layout.addWidget(self.tabView)
         main_layout.addWidget(self._status_bar)
+        main_layout.setSpacing(0)
+        main_layout.setContentsMargins(0,0,0,0)
+
 
         self.setLayout(main_layout)
 
