@@ -1,10 +1,8 @@
-import datetime
 import logging
 import pathlib
 import os
 import re
 import subprocess
-import threading
 import time
 from functools import wraps
 from typing import Iterable, Optional
@@ -13,9 +11,9 @@ import filelock
 import git
 import git.exc
 
-from binsync.data import User
+from binsync.data import User, GlobalConfig
 from binsync.core.errors import ExternalUserCommitError, MetadataNotFoundError
-from binsync.core.state import State
+from binsync.data.state import State, load_toml_from_file
 from binsync.core.scheduler import Scheduler, Job, SchedSpeed
 from binsync.core.cache import Cache
 
@@ -58,7 +56,6 @@ def atomic_git_action(f):
             priority=priority
         )
 
-        # set cache
         self._set_cache(f, ret_val, **kwargs)
 
         return ret_val
@@ -127,6 +124,9 @@ class Client:
         self.last_pull_attempt_ts = None  # type: Optional[float]
         self._last_commit_ts = None # type: Optional[float]
 
+        # load or update the global binsync config
+        self.global_config = self._load_or_update_config()
+
         self.active_remote = True
 
     def __del__(self):
@@ -137,6 +137,12 @@ class Client:
     # Initializers
     #
 
+    def _load_or_update_config(self):
+        config = GlobalConfig.load_from_file(None) or GlobalConfig(None)
+        config.last_bs_repo_path = self.repo_root
+        config.save()
+        return config
+
     def _get_or_init_user_branch(self):
         """
         Creates a user branch if the user is new, otherwise it gets the branch of the same
@@ -281,7 +287,6 @@ class Client:
         except Exception as e:
             l.warning(f"Internal Git Commit Error: {e}")
             return
-
         self._last_commit_ts = time.time()
         master_user_branch.commit = commit
         state._dirty = False
@@ -292,7 +297,7 @@ class Client:
         users = list()
         for ref in self._get_best_refs(repo).values():
             try:
-                metadata = State.load_toml_from_file("metadata.toml", client=self, tree=ref.commit.tree)
+                metadata = load_toml_from_file(ref.commit.tree, "metadata.toml", client=self)
                 user = User.from_metadata(metadata)
                 users.append(user)
             except Exception as e:
@@ -341,8 +346,13 @@ class Client:
                 self.repo.git.fetch("--all")
                 self.repo.git.pull("--all")
                 self._last_pull_ts = time.time()
+                self.active_remote = True
             except Exception as e:
                 l.debug(f"Pull exception {e}")
+                self.active_remote = False
+
+        if not self.active_remote:
+            return
 
         # preform a merge on each branch
         for branch in self.repo.branches:
@@ -353,7 +363,8 @@ class Client:
             try:
                 self.repo.git.merge()
             except Exception as e:
-                l.debug(f"Failed to merge on {branch} with {e}")
+                #l.debug(f"Failed to merge on {branch} with {e}")
+                pass
 
         self._update_cache()
 
@@ -372,8 +383,10 @@ class Client:
                 self.repo.remotes[self.remote].push(BINSYNC_ROOT_BRANCH)
                 self.repo.remotes[self.remote].push(self.user_branch_name)
             self._last_push_ts = time.time()
-            l.debug("Push completed successfully at %s", self._last_push_ts)
+            #l.debug("Push completed successfully at %s", self._last_push_ts)
+            self.active_remote = True
         except git.exc.GitCommandError as ex:
+            self.active_remote = False
             l.debug(f"Failed to push b/c {ex}")
 
     @property
@@ -384,11 +397,7 @@ class Client:
 
         :return:    True if there is a remote, False otherwise.
         """
-
-        if self.remote and any(r.name == self.remote for r in self.repo.remotes):
-            return self.active_remote
-
-        return False
+        return self.remote and any(r.name == self.remote for r in self.repo.remotes)
 
     #
     # Non-Atomic Public API
@@ -400,14 +409,16 @@ class Client:
         in the case of dirty files.
         """
         # attempt to commit dirty files in a update phase
-        master_state = self.get_state(user=self.master_user, no_cache=True)
+        master_state = self.get_state(no_cache=True)
         if master_state and master_state.dirty:
             self.commit_state(master_state, msg=commit_msg)
 
         # do a pull if there is a remote repo connected
+        self.last_pull_attempt_ts = time.time()
         if self.has_remote:
             self.pull()
 
+        self.last_push_attempt_ts = time.time()
         if self.has_remote:
             self.push()
 
